cvolume: Completed and Masur-Veech volumes of strata of quadratic differentials with odd zeros
==============================================================================================

Description
-----------

cvolume is a SageMath module to compute completed and Masur-Veech volumes of strata
of quadratic differentials with odd zeros.

License
-------

GPLv2+

Upstream Contact
----------------

- https://github.com/eduryev/cvolume
- https://github.com/passagemath/passagemath-pkg-cvolume
